HttpWrapPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • HttpWrapPlatform
Implementers

Constructors

HttpWrapPlatform()
Constructs the platform interface used by the generated plugin scaffold.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Returns the host platform version from the example plugin channel.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance HttpWrapPlatform
The active platform implementation for optional native integration.
getter/setter pair