HttpWrapPlatform constructor
HttpWrapPlatform()
Constructs the platform interface used by the generated plugin scaffold.
Implementation
HttpWrapPlatform() : super(token: _token);
Constructs the platform interface used by the generated plugin scaffold.
HttpWrapPlatform() : super(token: _token);