MethodChannelHttpWrap class
Default method-channel implementation kept for plugin scaffold parity.
- Inheritance
-
- Object
- PlatformInterface
- HttpWrapPlatform
- MethodChannelHttpWrap
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
Channel used by the generated example/platform-version integration.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
Returns the host platform version from the example plugin channel.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited